@@ -1,5 +1,6 @@
 from abc import abstractmethod
 from asyncio.tasks import Task
+from configparser import ConfigParser
 import threading
 import asyncio
 import queue
@@ -10,6 +11,7 @@ from functools import reduce
 from random import getrandbits, randrange
 from typing import Any, Callable, Coroutine, Optional, Tuple, TypeVar, Union, cast, List, Dict
 from textwrap import wrap
+from os import path
 
 from .constants import *
 from .logger.constants import *
@@ -202,29 +204,33 @@ class Bus(EventEmitter):
                  device_description: str = None,
                  disable_logger: bool = False,
                  disable_role_manager: bool = False,
+                 disable_settings: bool = False,
                  disable_brain: bool = False,
                  disable_dev_tools: bool = False,
                  hf2_portname: str = None,
-                 default_logger_min_priority: int = JD_LOGGER_PRIORITY_SILENT,
-                 role_manager_file_name: str = "./.jacdac/roles.json",
-                 settings_file_name: str = "./.jacdac/settings.json"
+                 default_logger_min_priority: int = None,
+                 storage_dir: str = None
                  ) -> None:
-        """Instantiates a new Jacdac bus
+        """Creates a new Jacdac bus.
+
+        All configuration options, aside form transports, can also be specified in ini configuration files ./jacdac.config, ./.jacdac/config.ini or setup.cfg.
 
         Args:
             transports (List[Transport]): packet transports
-            settings_file_name (str): Optional settings file location. Enables settings service.
+            storage_dir (str): Optional settings directory where settings, roles are stored.
             device_id (str, optional): Optional device identifier. Auto-generated if not specified.
             product_identifier (int, optional): Optional product identifier.
             device_description (str, optional): Optional device description.
             disable_logger (bool, optional): Disable the logger service. Defaults to False.
             disable_role_manager (bool, optional): Disable the role manager service. Defaults to False.
+            disable_settings (bool, optional): Disable the settings service. Defaults to False.
             disable_brain (bool, optional): Disable unique brain service. Defaults to False.
             default_logger_min_priority (int, optional): Optional mininimum logger priority. Defaults to JD_LOGGER_PRIORITY_SILENT.
             disable_dev_tools (bool, optional): Do not try to connect to developer tools server.
             hf2_portname (str, optional): port name exposing HF2 packets.
         """
         super().__init__(self)
+
         self.devices: List['Device'] = []
         self.unattached_clients: List['Client'] = []
         self.all_clients: List['Client'] = []
@@ -232,20 +238,36 @@ class Bus(EventEmitter):
         self.logger: Optional[LoggerServer] = None
         self.role_manager: Optional[RoleManagerServer] = None
         self.pipes: List['InPipe'] = []
-
-        self.product_identifier = product_identifier
-        self.firmware_version = firmware_version
-        self.device_description = device_description
-        self.disable_brain = disable_brain
-        self.disable_logger = disable_logger
-        self.disable_role_manager = disable_role_manager
-        self.default_logger_min_priority = default_logger_min_priority
-        self.settings_file_name = settings_file_name
-        self.role_manager_file_name = role_manager_file_name
         self._event_counter = 0
 
-        if device_id is None:
-            device_id = rand_u64().hex()
+        # merge .ctor configuration with files
+        config = ConfigParser()
+        config.read(["./jacdac.ini", "./.jacdac/config.ini", "./setup.cfg"])
+        if not config.has_section("jacdac"):
+            cfg = config.add_section("jacdac")
+        cfg = config["jacdac"]
+        device_id = device_id or cfg.get(
+            "device_id", rand_u64().hex())
+        self.product_identifier: Optional[int] = product_identifier or cfg.getint(
+            "product_identifier", None)
+        self.firmware_version: Optional[str] = firmware_version or cfg.get(
+            "firmware_version", None)
+        self.device_description: Optional[str] = device_description
+        self.disable_brain = disable_brain or cfg.getboolean(
+            "disable_brain", False)
+        self.disable_logger = disable_logger or cfg.getboolean(
+            "disable_logger", False)
+        self.disable_settings = disable_settings or cfg.getboolean(
+            "disable_settings", False)
+        self.disable_dev_tools = disable_dev_tools or cfg.getboolean(
+            "disable_dev_tools", False)
+        self.disable_role_manager = disable_role_manager or cfg.getboolean(
+            "disable_role_manager", False)
+        self.default_logger_min_priority = default_logger_min_priority or cfg.getint(
+            "default_logger_min_priority", JD_LOGGER_PRIORITY_SILENT)
+        self.storage_dir = storage_dir or cfg.get("storage_dir", "./.jacdac")
+        self.hr2_portname = hf2_portname or cfg.get("hf2_portname")
+
         self.self_device = Device(self, device_id, bytearray(4))
         self.process_thread = threading.Thread(target=self._process_task)
         self.transports: List[Transport] = transports or []
@@ -300,11 +322,10 @@ class Bus(EventEmitter):
         if not self.disable_logger:
             self.logger = LoggerServer(self)
 
-        if not self.disable_role_manager:
-            self.role_manager = RoleManagerServer(
-                self, self.role_manager_file_name)
+        if self.storage_dir and not self.disable_role_manager:
+            self.role_manager = RoleManagerServer(self)
 
-        if self.settings_file_name:
+        if self.storage_dir and not self.disable_settings:
             from .settings.server import SettingsServer
             self.settings = SettingsServer(self)
 
@@ -1106,9 +1127,10 @@ class UniqueBrainServer(Server):
 
 
 class RoleManagerServer(Server):
-    def __init__(self, bus: Bus, file_name: str) -> None:
+    def __init__(self, bus: Bus) -> None:
         super().__init__(bus, JD_SERVICE_CLASS_ROLE_MANAGER)
 
+        file_name = path.join(self.bus.storage_dir, "roles.json")
         from jacdac.settings_file import SettingsFile
         self.settings = SettingsFile(file_name)
         self.auto_bind = 1
@@ -1540,4 +1562,4 @@ class Device(EventEmitter):
                (not c.broadcast and c.service_index == pkt.service_index):
                 # log(`handle pkt at ${client.role} rep=${pkt.serviceCommand}`)
                 c.device = self
-                c.handle_packet_outer(pkt)
\ No newline at end of file
+                c.handle_packet_outer(pkt)
